pub struct validateP2pAddrCall {
pub p2pAddr: String,
}Expand description
Function with signature validateP2pAddr(string) and selector 0x15f31835.
function validateP2pAddr(string memory p2pAddr) external pure;Fields
p2pAddr: StringTrait Implementations
Sourceimpl Clone for validateP2pAddrCall
impl Clone for validateP2pAddrCall
Sourcefn clone(&self) -> validateP2pAddrCall
fn clone(&self) -> validateP2pAddrCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for validateP2pAddrCall
impl Debug for validateP2pAddrCall
Sourceimpl Default for validateP2pAddrCall
impl Default for validateP2pAddrCall
Sourcefn default() -> validateP2pAddrCall
fn default() -> validateP2pAddrCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for validateP2pAddrCall
impl<'de> Deserialize<'de> for validateP2pAddrCall
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for validateP2pAddrCall
impl Hash for validateP2pAddrCall
Sourceimpl PartialEq for validateP2pAddrCall
impl PartialEq for validateP2pAddrCall
Sourceimpl Serialize for validateP2pAddrCall
impl Serialize for validateP2pAddrCall
Sourceimpl SolCall for validateP2pAddrCall
impl SolCall for validateP2pAddrCall
Sourcetype Parameters<'a> = (String,)
type Parameters<'a> = (String,)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<validateP2pAddrCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<validateP2pAddrCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding [TokenSeq] type.
Sourcetype Return = validateP2pAddrReturn
type Return = validateP2pAddrReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<validateP2pAddrCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<validateP2pAddrCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding [TokenSeq] type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
fn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
fn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
fn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
fn abi_encode(&self) -> Vec<u8> ⓘ
fn abi_encode(&self) -> Vec<u8> ⓘ
ABI encode the call to the given buffer with its selector.
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
fn abi_encode_returns(ret: &Self::Return) -> Vec<u8> ⓘ
ABI encode the call’s return value.
impl Eq for validateP2pAddrCall
impl StructuralPartialEq for validateP2pAddrCall